<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassX</source>
        <translation>O KeePassX</translation>
    </message>
    <message>
        <source>KeePassX is distributed under the term of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Revision</source>
        <translation>Rewizja</translation>
    </message>
    <message>
        <source>Using:</source>
        <translation>Używanie:</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-uzupełnianie - KeePassX</translation>
    </message>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Nie mogę znaleźć wpisu, który by pasował do tytułu okna: </translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Swkwencja</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Domyślna sekwencja</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Auto-Type - KeePassX</source>
        <translation>Auto-uzupełnianie - KeePassX</translation>
    </message>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Wybierz wpis do auto-uzupełniania:</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Wprowadź hasło:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Wprowadź ponownie hasło:</translation>
    </message>
    <message>
        <source>Key file</source>
        <translation>Plik klucza</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Stwórz</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Pliki kluczy</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Utwórz plik klucza</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Nie można utworzyć pliku klucza :</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Wybierz plik z kluczem</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Czy naprawdę chcesz użyć pusty ciąg znaków jako hasło ?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Podano różne hasła.</translation>
    </message>
    <message>
        <source>Failed to set key file</source>
        <translation>Błąd w ustawianiu pliku z kluczem</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Błąd w ustawieniu %1 jako plik klucza:
%2</translation>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Wprowadź klucz główny</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Plik klucza:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Nie można otworzyć bazy kluczy.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Nie mogę otworzyć pliku z kluczem</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Pliki kluczy</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Wybierz plik z kluczem</translation>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Napraw bazę</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Nie mogę otworzyć pliku z kluczem</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Pomyślnie otworzono bazę. Nic do zrobienia.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Nie można otworzyć bazy kluczy.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sukces</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>Baza została naprawiona
Możesz teraz ją już zapisać.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Nie mogę naprawić bazę.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Nazwa bazy danych:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Opis bazy danych:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Liczba rund szyfrowania:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Domyślny użytkownik:</translation>
    </message>
    <message>
        <source>Use recycle bin:</source>
        <translation>Korzystaj z kosza:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Test sprawności</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Max. ilość wpisów w historii:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Max. rozmiar historii:</translation>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Baza danych KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Otwórz bazę danych</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Nie znaleziono pliku!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>Otwórz bazę danych KeePass 1</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>Baza danych KeePass 1</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Wszystkie pliki (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Zamknąć?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Zapisać zmiany?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; został zmieniony.
Zapisać zmiany?</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Błąd w zapisywaniu bazy kluczy.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Zapisz bazę danych jako</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nowa baza danych</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>zablokowana</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassX.
Do you want to open it anyway? Alternatively the database is opened read-only.</source>
        <translation>Baza, którą próbujesz otworzyć, jest zablokowana przez inną instancję KeePassX.
Czy chcesz ją otworzyć pomimo tego? Inaczej baza będzie otwarta tylko do odczytu.</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Zablokuj bazę</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Nie można zablokować bazy, którą edytujesz.
Naciśnij anuluj, aby zakończyć zmiany albo porzucić je.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Baza nie została nigdy zapisana.
Możesz ją zapisać albo przestać blokować.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Baza została zmodyfikowana.
Czy chcesz zapisać przed zablokowaniem jej?
W przeciwnym wypadku zmiany zostaną porzucone.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; jest w trybie edytowania.
Odrzucić zmiany i zamknąć?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Eksport bazy danych do pliku CSV</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>plik CSV</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Błąd przy zapisywaniu pliku CSV.</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassX.
Do you want to save it anyway?</source>
        <translation>Baza, którą próbujesz zapisać jest zablokowana przez inną instancję KeePassX.
Czy chcesz zapisać mimo to?</translation>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Zmień główne hasło</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Skasować wpis?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Czy na pewno całkowicie usunąć wpis &quot;%1&quot; ?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Usunąć wpisy?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Czy na prawdę chcesz usunąć %1 wpisów na dobre?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Przenieść wpisy do kosza?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Czy na pewno chcesz przenieść %n wpis do kosza?</numerusform><numerusform>Czy na pewno chcesz przenieść %n wpisów do kosza?</numerusform><numerusform>Czy na pewno chcesz przenieść %n wpisów do kosza?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Usunąć grupę?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Czy na pewno całkowicie usunąć grupę &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Bieżąca grupa</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nie mogę wyliczyć głównego klucza</translation>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Wpis</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-uzupełnianie</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Historia wpisu</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Dodaj wpis</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Edycja wpisu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Podano różne hasła.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nowy atrybut</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Wybierz plik</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Nie można otworzyć pliku</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Zapisz załącznik</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Nie można zapisać załącznika:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Jutro</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n tydzień</numerusform><numerusform>%n tygodni(e)</numerusform><numerusform>%n tygodni(e)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n miesiąc</numerusform><numerusform>%n miesiąc(e)</numerusform><numerusform>%n miesiąc(e)</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 rok</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Dodatkowe atrybuty</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Załączniki</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otwórz</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Włącz auto-uzupełnianie dla tego wpisu</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the group</source>
        <translation>Dziedzicz domyślną sekwencję auto-uzupełniania z grupy</translation>
    </message>
    <message>
        <source>Use custom Auto-Type sequence:</source>
        <translation>Używaj niestandardowej sekwencji auto-uzupełniania:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Tytuł okna:</translation>
    </message>
    <message>
        <source>Use default sequence</source>
        <translation>Korzystaj z domyślnej sekwencji</translation>
    </message>
    <message>
        <source>Set custom sequence:</source>
        <translation>Ustaw niestandardową sekwencję:</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Pokaż</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Przywróć</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Usuń wszystkie</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Powtórz:</translation>
    </message>
    <message>
        <source>Gen.</source>
        <translation>Gen.</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Wygasa</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Prezentuje</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Notatki:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Dodaj grupę</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Edytuj grupę</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Dziedzicz z nadrzędnej grupy (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notatki</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Wygasa</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Auto-type</source>
        <translation>Auto-uzupełnianie</translation>
    </message>
    <message>
        <source>Use default auto-type sequence of parent group</source>
        <translation>Korzystaj z domyślnej sekwencji auto-uzupełniania z nadrzędnej grupy</translation>
    </message>
    <message>
        <source>Set default auto-type sequence</source>
        <translation>Ustaw domyślną sekwencję auto-uzupełniania</translation>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Use default icon</source>
        <translation>Ustaw domyślną ikonę</translation>
    </message>
    <message>
        <source>Use custom icon</source>
        <translation>Ustaw niestandardową ikonę</translation>
    </message>
    <message>
        <source>Add custom icon</source>
        <translation>Dodaj niestandardową ikonę</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Usuń niestandardową ikonę</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrazy</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Wybierz obraz</translation>
    </message>
    <message>
        <source>Can&apos;t delete icon!</source>
        <translation>Nie można usunąć ikony!</translation>
    </message>
    <message numerus="yes">
        <source>Can&apos;t delete icon. Still used by %n item(s).</source>
        <translation><numerusform>Nie mogę usunąć ikony. Nadal używana przez %n wpis.</numerusform><numerusform>Nie mogę usunąć ikony. Nadal używana przez %n wpisów.</numerusform><numerusform>Nie mogę usunąć ikony. Nadal używana przez %n wpisów.</numerusform></translation>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Stworzone:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Modyfikowane:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid:</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Ostatnia modyfikacja</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Kosz</translation>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importuj bazę danych KeePass1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Nie można otworzyć bazy kluczy.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Nie można otworzyć pliku z kluczem.</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>To nie baza KeePass.</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Niewspierany algorytm szyfrowania.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niewspierana wersja bazy KeePass.</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nie mogę wyliczyć głównego klucza</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>To nie baza KeePass.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niewspierana wersja bazy KeePass.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Błędny klucz lub baza jest uszkodzona.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Nie mogę wyliczyć głównego klucza</translation>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation>Wybrany plik jest bazą starego KeePassX 1 (.kdb).

Możesz zaimportować ją przez wybranie Baza &gt; &apos;Importuj bazę danych KeePass 1&apos;.
Nie będzie można skonwertować nowej bazy do starego programu KeePassX 0.4.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Błąd krytyczny podczas testowania funkcji kryptograficznych.</translation>
    </message>
    <message>
        <source>KeePassX - Error</source>
        <translation>KeePassX - Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Database</source>
        <translation>Baza danych</translation>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Niedawne bazy danych</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Entries</source>
        <translation>Wpisy</translation>
    </message>
    <message>
        <source>Copy attribute to clipboard</source>
        <translation>Skopiuj atrybut do schowka</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Grupy</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Otwórz bazę danych</translation>
    </message>
    <message>
        <source>Save database</source>
        <translation>Zapisz bazę danych</translation>
    </message>
    <message>
        <source>Close database</source>
        <translation>Zamknij bazę danych</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nowa baza danych</translation>
    </message>
    <message>
        <source>Add new entry</source>
        <translation>Dodaj nowy wpis</translation>
    </message>
    <message>
        <source>View/Edit entry</source>
        <translation>Podgląd/edycja wpisu</translation>
    </message>
    <message>
        <source>Delete entry</source>
        <translation>Usuń wpis</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Dodaj nową grupę</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Edytuj grupę</translation>
    </message>
    <message>
        <source>Delete group</source>
        <translation>Usuń grupę</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Zapisz bazę danych jako</translation>
    </message>
    <message>
        <source>Change master key</source>
        <translation>Zmień główne hasło</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Ustawienia bazy danych</translation>
    </message>
    <message>
        <source>Import KeePass 1 database</source>
        <translation>Importuj bazę danych KeePass 1</translation>
    </message>
    <message>
        <source>Clone entry</source>
        <translation>Sklonuj wpis</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Znajdź</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Skopiuj użytkownika do schowka</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Skopiuj hasło do schowka</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Perform Auto-Type</source>
        <translation>Wykonaj auto-uzupełnianie</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Otwórz URL</translation>
    </message>
    <message>
        <source>Lock databases</source>
        <translation>Zablokuj bazy</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Notatki</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Pokaż pasek narzędziowy</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>Tylko do odczytu</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Pokaż/ukryj okno</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <source>Copy username</source>
        <translation>Skopiuj użytkownika</translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation>Skopiuj hasło</translation>
    </message>
    <message>
        <source>Export to CSV file</source>
        <translation>Eksport do pliku CSV</translation>
    </message>
    <message>
        <source>Repair database</source>
        <translation>Napraw bazę</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>Baza KeePass 2</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Zapisz naprawioną bazę</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Błąd przy zapisie bazy.</translation>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Length:</source>
        <translation>Długość</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Typy znaków</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Duże litery</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Małe litery</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Liczby</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Znaki specjalne</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Wyklucz podobnie wyglądające znaki</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Zapewnij, że hasło będzie zawierało znaki ze wszystkich grup</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Zaakceptuj</translation>
    </message>
</context>
<context>
    <name>QCommandLineParser</name>
    <message>
        <source>Displays version information.</source>
        <translation>Wyświetl informację o wersji.</translation>
    </message>
    <message>
        <source>Displays this help.</source>
        <translation>Wyświetla ten dialog.</translation>
    </message>
    <message>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Nie znana opcja &apos;%1&apos;:</translation>
    </message>
    <message>
        <source>Unknown options: %1.</source>
        <translation>Nie znana opcja: %1.</translation>
    </message>
    <message>
        <source>Missing value after &apos;%1&apos;.</source>
        <translation>Brakująca wartość po &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Unexpected value after &apos;%1&apos;.</source>
        <translation>Nieoczekiwana wartość po &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>[options]</source>
        <translation>[options]</translation>
    </message>
    <message>
        <source>Usage: %1</source>
        <translation>Używanie: %1</translation>
    </message>
    <message>
        <source>Options:</source>
        <translation>Opcje:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>Argumenty:</translation>
    </message>
</context>
<context>
    <name>QSaveFile</name>
    <message>
        <source>Existing file %1 is not writable</source>
        <translation>Istniejący plik %1 jest nie do zapisu</translation>
    </message>
    <message>
        <source>Writing canceled by application</source>
        <translation>Zapisywanie anulowane przez aplikację</translation>
    </message>
    <message>
        <source>Partial write. Partition full?</source>
        <translation>Częściowy zapis. Pełny dysk?</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Błąd wewnętrzny zlib podczas kompresowania:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Błąd w zapisie na urządzenie:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Błąd w otwieraniu z urządzenia:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Błąd w odczycie danych z urządzenia:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Błąd wewnętrzny zlib podczas dekompresowania:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Format gzip nie wspierany przez tą wersję zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Błąd wewnętrzny zlib:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Find:</source>
        <translation>Znajdź:</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Rozróżniaj wielkość znaków</translation>
    </message>
    <message>
        <source>Current group</source>
        <translation>Bieżąca grupa</translation>
    </message>
    <message>
        <source>Root group</source>
        <translation>Główna grupa</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Ustawienia aplikacji</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Główne</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Pamiętaj ostatnią bazę</translation>
    </message>
    <message>
        <source>Open previous databases on startup</source>
        <translation>Otwórz poprzednią bazę podczas startu</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Automatycznie zapisz przy wyjściu</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Automatycznie zapisz po każdej zmianie</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Zminimalizuj po skopiowaniu do schowka</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Użyj ikony grupy podczas tworzenia wpisu</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Globalny skrót auto-uzupełnianie</translation>
    </message>
    <message>
        <source>Use entry title to match windows for global auto-type</source>
        <translation>Wykorzystaj tytuł wpisu do dopasowania dla globalnego auto-wpisywania</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Pokaż ikonę w zasobniku systemowym</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Schowaj okno do zasobnika podczas minimalizacji</translation>
    </message>
    <message>
        <source>Remember last key files</source>
        <translation>Zapamiętaj ostatni plik klucza</translation>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Wyczyść schowek po</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Zablokuj bazę po nieaktywności</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Domyślnie pokazuj hasła</translation>
    </message>
    <message>
        <source>Always ask before performing auto-type</source>
        <translation>Zawsze pytaj przed wykonaniem auto-uzupełninia</translation>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Odblokuj bazę</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome!</source>
        <translation>Witaj!</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>KeePassX - cross-platform password manager</source>
        <translation>KeePassX - wieloplatformowy menadżer haseł</translation>
    </message>
    <message>
        <source>filename of the password database to open (*.kdbx)</source>
        <translation>nazwa pliku z bazą haseł do otwarcia (*.kdbx)</translation>
    </message>
    <message>
        <source>path to a custom config file</source>
        <translation>ścieżka do pliku z ustawieniami</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>plik klucza bazy</translation>
    </message>
</context>
</TS>